@@ -6,7 +6,7 @@ name = 'web_2_album'
 import cached_url
 from bs4 import BeautifulSoup
 import export_to_telegraph
-from telegram_util import matchKey, cutCaption, getWid, parseDomain
+from telegram_util import matchKey, cutCaption, getWid, parseDomain, getTitleFromText
 from telegram_util import AlbumResult as Result
 import readee
 import time
@@ -33,6 +33,14 @@ def getCap(b, path):
 		b.find('div', class_='post f') or 
 		b.find('div', class_='topic-richtext') or
 		b.find('p', id='first', class_='lead'))
+	if 'douban' in path and 'group/topic' in path:
+		title = b.find('title').text.strip()
+		content = b.find('div', class_='topic-richtext')
+		for item in content.find_all('p'):
+			item.append('\n\n')
+		for item in content.find_all('a'):
+			item.decompose()
+		return '【%s】\n\n%s' % (getTitleFromText(title), content.text.strip())
 	if 'douban' in path:
 		topic = b.find('p', class_='topic-say')
 		topic = topic and topic.text
